<?php
/*
* Copyright (C) 2020 Orange
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*/ 

/*
* Bind 9.9
* 
* Module:	Bind Server 9.9
* Version:  0.1
* Created:  2020-05-04 by Marius Bostiog
*/

/* do NOT run this script through a web browser */
if (!isset($_SERVER["argv"][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
   die("<br><strong>This script is only meant to run at the command line.</strong>");
}

$no_http_headers = true;
$initime = microtime(true);

//input arguments for the script passed by Cacti, these will be the device hostname and community
$comm = $_SERVER["argv"][1];
$hostname = $_SERVER["argv"][2];
$stats = $_SERVER["argv"][3];
$name = "$stats";

// log file location
$debugMode = "off"; // ATTENTION! Be careful with setting it "on". Only activate if necessary, or cacti.log will be filled.
$strLogFile = dirname(__FILE__).'/../log/cacti.log';

$INQ = [
    "inqa" => ".1.3.6.1.4.1.1368.150.1.1.1", //Incoming Queries type A
    "inqns" => ".1.3.6.1.4.1.1368.150.1.1.2", //Incoming Queries type NS
    "inqcname" => ".1.3.6.1.4.1.1368.150.1.1.5", //Incoming Queries type CNAME
    "inqsoa" => ".1.3.6.1.4.1.1368.150.1.1.6", //Incoming Queries type SOA
    "inqnull" => ".1.3.6.1.4.1.1368.150.1.1.10", //Incoming Queries type NULL
    "inqptr" => ".1.3.6.1.4.1.1368.150.1.1.12", //Incoming Queries type PTR
    "inqmx" => ".1.3.6.1.4.1.1368.150.1.1.15", //Incoming Queries type MX
    "inqtxt" => ".1.3.6.1.4.1.1368.150.1.1.16", //Incoming Queries type TXT
    "inqaaaa" => ".1.3.6.1.4.1.1368.150.1.1.28", //Incoming Queries type AAAA
    "inqsrv" => ".1.3.6.1.4.1.1368.150.1.1.33", //Incoming Queries type SRV
    "inqnaptr" => ".1.3.6.1.4.1.1368.150.1.1.35", //Incoming Queries type NAPTR
    "inqa6" => ".1.3.6.1.4.1.1368.150.1.1.38", //Incoming Queries type A6
    "inqds" => ".1.3.6.1.4.1.1368.150.1.1.43", //Incoming Queries type DS
    "inqrrsig" => ".1.3.6.1.4.1.1368.150.1.1.46", //Incoming Queries type RRSIG
    "inqnsec" => ".1.3.6.1.4.1.1368.150.1.1.47", //Incoming Queries type NSEC
    "inqnsec3" => ".1.3.6.1.4.1.1368.150.1.1.50", //Incoming Queries type NSEC3
    "inqnsec3param" => ".1.3.6.1.4.1.1368.150.1.1.51", //Incoming Queries type NSEC3PARAM
    "inqspf" => ".1.3.6.1.4.1.1368.150.1.1.63", //Incoming Queries type SPF
    "inqtkey" => ".1.3.6.1.4.1.1368.150.1.1.74", //Incoming Queries type TKEY
    "inqtsig" => ".1.3.6.1.4.1.1368.150.1.1.75", //Incoming Queries type TSIG
    "inqixfr" => ".1.3.6.1.4.1.1368.150.1.1.76", //Incoming Queries type IXFR
    "inqaxfr" => ".1.3.6.1.4.1.1368.150.1.1.77", //Incoming Queries type AXFR
    "inqstar" => ".1.3.6.1.4.1.1368.150.1.1.80", //Incoming Queries type *
    "inqta" => ".1.3.6.1.4.1.1368.150.1.1.86" //Incoming Queries type TA
];

$OUTQ = [
    "outqa" => ".1.3.6.1.4.1.1368.150.1.2.1", // Outgoing Queries type A
    "outqns" => ".1.3.6.1.4.1.1368.150.1.2.2", // Outgoing Queries type NS
    "outqcname" => ".1.3.6.1.4.1.1368.150.1.2.5", // Outgoing Queries type CNAME
    "outqsoa" => ".1.3.6.1.4.1.1368.150.1.2.6", // Outgoing Queries type SOA
    "outqnull" => ".1.3.6.1.4.1.1368.150.1.2.10", // Outgoing Queries type NULL
    "outqptr" => ".1.3.6.1.4.1.1368.150.1.2.12", // Outgoing Queries type PTR
    "outqmx" => ".1.3.6.1.4.1.1368.150.1.2.15", // Outgoing Queries type MX
    "outqtxt" => ".1.3.6.1.4.1.1368.150.1.2.16", // Outgoing Queries type TXT
    "outqaaaa" => ".1.3.6.1.4.1.1368.150.1.2.28", // Outgoing Queries type AAAA
    "outqsrv" => ".1.3.6.1.4.1.1368.150.1.2.33", // Outgoing Queries type SRV
    "outqnaptr" => ".1.3.6.1.4.1.1368.150.1.2.35", // Outgoing Queries type NAPTR
    "outqa6" => ".1.3.6.1.4.1.1368.150.1.2.38", // Outgoing Queries type A6
    "outqds" => ".1.3.6.1.4.1.1368.150.1.2.43", // Outgoing Queries type DS
    "outqrrsig" => ".1.3.6.1.4.1.1368.150.1.2.46", // Outgoing Queries type RRSIG
    "outqnsec" => ".1.3.6.1.4.1.1368.150.1.2.47", // Outgoing Queries type NSEC
    "outqnsec3" => ".1.3.6.1.4.1.1368.150.1.2.50", // Outgoing Queries type NSEC3
    "outqnsec3param" => ".1.3.6.1.4.1.1368.150.1.2.51", // Outgoing Queries type NSEC3PARAM
    "outqspf" => ".1.3.6.1.4.1.1368.150.1.2.63", // Outgoing Queries type SPF
    "outqtkey" => ".1.3.6.1.4.1.1368.150.1.2.74", // Outgoing Queries type TKEY
    "outqtsig" => ".1.3.6.1.4.1.1368.150.1.2.75", // Outgoing Queries type TSIG
    "outqixfr" => ".1.3.6.1.4.1.1368.150.1.2.76", // Outgoing Queries type IXFR
    "outqaxfr" => ".1.3.6.1.4.1.1368.150.1.2.77", // Outgoing Queries type AXFR
    "outqstar" => ".1.3.6.1.4.1.1368.150.1.2.80", // Outgoing Queries type *
    "outqta" => ".1.3.6.1.4.1.1368.150.1.2.86" // Outgoing Queries type TA
];

$RES = [
    "resmis" => ".1.3.6.1.4.1.1368.150.1.3.1", // Resolver mismatch responses received
    "resipv4qs" => ".1.3.6.1.4.1.1368.150.1.3.2", // Resolver IPv4 queries sent
    "resipv4rr" => ".1.3.6.1.4.1.1368.150.1.3.3", // Resolver IPv4 responses received
    "resnxdomr" => ".1.3.6.1.4.1.1368.150.1.3.4", // Resolver NXDOMAIN received
    "resservfr" => ".1.3.6.1.4.1.1368.150.1.3.5", // Resolver SERVFAIL received
    "resformr" => ".1.3.6.1.4.1.1368.150.1.3.6", // Resolver FORMERR received
    "resednsqf" => ".1.3.6.1.4.1.1368.150.1.3.7", // Resolver EDNS(0) query failures
    "restrunrr" => ".1.3.6.1.4.1.1368.150.1.3.8", // Resolver truncated responses received
    "resqr" => ".1.3.6.1.4.1.1368.150.1.3.9", // Resolver query retries
    "resqto" => ".1.3.6.1.4.1.1368.150.1.3.10", // Resolver query timeouts
    "resipv4nsaf" => ".1.3.6.1.4.1.1368.150.1.3.11", // Resolver IPv4 NS address fetches
    "resipv4nsaff" => ".1.3.6.1.4.1.1368.150.1.3.12", // Resolver IPv4 NS address fetch failed
    "resdnssecva" => ".1.3.6.1.4.1.1368.150.1.3.13", // Resolver DNSSEC validation attempted
    "resdnssecvs" => ".1.3.6.1.4.1.1368.150.1.3.14", // Resolver DNSSEC validation succeeded
    "resdnssecnxvs" => ".1.3.6.1.4.1.1368.150.1.3.15" // Resolver DNSSEC NX validation succeeded
];

$RTT = [
    "10ms" => ".1.3.6.1.4.1.1368.150.1.4.1", // RTT queries with RTT < 10ms
    "10_100ms" => ".1.3.6.1.4.1.1368.150.1.4.2", // RTT queries with RTT 10-100ms
    "100_500ms" => ".1.3.6.1.4.1.1368.150.1.4.3", // RTT queries with RTT 100-500ms
    "500_800ms" => ".1.3.6.1.4.1.1368.150.1.4.4", // RTT queries with RTT 500-800ms
    "800_1600ms" => ".1.3.6.1.4.1.1368.150.1.4.5", // RTT queries with RTT 800-1600ms
    "1600ms" => ".1.3.6.1.4.1.1368.150.1.4.6" // RTT queries with RTT > 1600ms
];

$IO = [
    "udp4o" => ".1.3.6.1.4.1.1368.150.1.5.1", // I/O UDP/IPv4 sockets opened
    "udp4c" => ".1.3.6.1.4.1.1368.150.1.5.2", // I/O UDP/IPv4 sockets closed
    "udp4a" => ".1.3.6.1.4.1.1368.150.1.5.3", // I/O UDP/IPv4 sockets active
    "udp4f" => ".1.3.6.1.4.1.1368.150.1.5.4", // I/O UDP/IPv4 socket bind failures
    "tcp4o" => ".1.3.6.1.4.1.1368.150.1.5.5", // I/O TCP/IPv4 sockets opened
    "tcp4c" => ".1.3.6.1.4.1.1368.150.1.5.6", // I/O TCP/IPv4 sockets closed
    "tcp4a" => ".1.3.6.1.4.1.1368.150.1.5.7", // I/O TCP/IPv4 sockets active
    "tcp4f" => ".1.3.6.1.4.1.1368.150.1.5.8", // I/O TCP/IPv4 socket bind failures
    "udp4e" => ".1.3.6.1.4.1.1368.150.1.5.9", // I/O UDP/IPv4 recv errors
    "tcp4e" => ".1.3.6.1.4.1.1368.150.1.5.10", // I/O TCP/IPv4 recv errors
    "udp4es" => ".1.3.6.1.4.1.1368.150.1.5.11", // I/O UDP/IPv4 connections established
    "tcp4es" => ".1.3.6.1.4.1.1368.150.1.5.12", // I/O TCP/IPv4 connections established
    "tcp4ac" => ".1.3.6.1.4.1.1368.150.1.5.13", // I/O TCP/IPv4 connections accepted
    "rawso" => ".1.3.6.1.4.1.1368.150.1.5.14", // I/O Raw sockets opened
    "rawsa" => ".1.3.6.1.4.1.1368.150.1.5.15", // I/O Raw sockets active
    "rawsc" => ".1.3.6.1.4.1.1368.150.1.5.16" // I/O Raw sockets closed
];


function getData($stats, $comm, $hostname, $name){

foreach($stats as $key => $value) {
    $dataFetch = snmp2_get($hostname, $comm, $value);
    $dataE = explode(':', $dataFetch);
    $dataVal = explode(' ', trim($dataE[1]));

    switch ($key){
        case "inqa":
            $inqa = $dataVal[0];
            break;
        case "inqns":
            $inqns = $dataVal[0];
            break;
        case "inqcname":
            $inqcname = $dataVal[0];
            break;
        case "inqsoa":
            $inqsoa = $dataVal[0];
            break;
        case "inqnull":
            $inqnull = $dataVal[0];
            break;
        case "inqptr":
            $inqptr = $dataVal[0];
            break;
        case "inqmx":
            $inqmx = $dataVal[0];
            break;
        case "inqtxt":
            $inqtxt = $dataVal[0];
            break;
        case "inqaaaa":
            $inqaaaa = $dataVal[0];
            break;
        case "inqsrv":
            $inqsrv = $dataVal[0];
            break;
        case "inqnaptr":
            $inqnaptr = $dataVal[0];
            break;
        case "inqa6":
            $inqa6 = $dataVal[0];
            break;
        case "inqds":
            $inqds = $dataVal[0];
            break;
        case "inqrrsig":
            $inqrrsig = $dataVal[0];
            break;
        case "inqnsec":
            $inqnsec = $dataVal[0];
            break;
        case "inqnsec3":
            $inqnsec3 = $dataVal[0];
            break;
        case "inqnsec3param":
            $inqnsec3param = $dataVal[0];
            break;
        case "inqspf":
            $inqspf = $dataVal[0];
            break;
        case "inqtkey":
            $inqtkey = $dataVal[0];
            break;
        case "inqtsig":
            $inqtsig = $dataVal[0];
            break;
        case "inqixfr":
            $inqixfr = $dataVal[0];
            break;
        case "inqaxfr":
            $inqaxfr = $dataVal[0];
            break;
        case "inqstar":
            $inqstar = $dataVal[0];
            break;
        case "inqta":
            $inqta = $dataVal[0];
            break;
        case "outqa":
            $outqa = $dataVal[0];
            break;
        case "outqns":
            $outqns = $dataVal[0];
            break;
        case "outqcname":
            $outqcname = $dataVal[0];
            break;
        case "outqsoa":
            $outqsoa = $dataVal[0];
            break;
        case "outqnull":
            $outqnull = $dataVal[0];
            break;
        case "outqptr":
            $outqptr = $dataVal[0];
            break;
        case "outqmx":
            $outqmx = $dataVal[0];
            break;
        case "outqtxt":
            $outqtxt = $dataVal[0];
            break;
        case "outqaaaa":
            $outqaaaa = $dataVal[0];
            break;
        case "outqsrv":
            $outqsrv = $dataVal[0];
            break;
        case "outqnaptr":
            $outqnaptr = $dataVal[0];
            break;
        case "outqa6":
            $outqa6 = $dataVal[0];
            break;
        case "outqds":
            $outqds = $dataVal[0];
            break;
        case "outqrrsig":
            $outqrrsig = $dataVal[0];
            break;
        case "outqnsec":
            $outqnsec = $dataVal[0];
            break;
        case "outqnsec3":
            $outqnsec3 = $dataVal[0];
            break;
        case "outqnsec3param":
            $outqnsec3param = $dataVal[0];
            break;
        case "outqspf":
            $outqspf = $dataVal[0];
            break;
        case "outqtkey":
            $outqtkey = $dataVal[0];
            break;
        case "outqtsig":
            $outqtsig = $dataVal[0];
            break;
        case "outqixfr":
            $outqixfr = $dataVal[0];
            break;
        case "outqaxfr":
            $outqaxfr = $dataVal[0];
            break;
        case "outqstar":
            $outqstar = $dataVal[0];
            break;
        case "outqta":
            $outqta = $dataVal[0];
            break;
        case "resmis":
            $resmis = $dataVal[0];
            break;
        case "resipv4qs":
            $resipv4qs = $dataVal[0];
            break;
        case "resipv4rr":
            $resipv4rr = $dataVal[0];
            break;
        case "resnxdomr":
            $resnxdomr = $dataVal[0];
            break;
        case "resservfr":
            $resservfr = $dataVal[0];
            break;
        case "resformr":
            $resformr = $dataVal[0];
            break;
        case "resednsqf":
            $resednsqf = $dataVal[0];
            break;
        case "restrunrr":
            $restrunrr = $dataVal[0];
            break;
        case "resqr":
            $resqr = $dataVal[0];
            break;
        case "resqto":
            $resqto = $dataVal[0];
            break;
        case "resipv4nsaf":
            $resipv4nsaf = $dataVal[0];
            break;
        case "resipv4nsaff":
            $resipv4nsaff = $dataVal[0];
            break;
        case "resdnssecva":
            $resdnssecva = $dataVal[0];
            break;
        case "resdnssecvs":
            $resdnssecvs = $dataVal[0];
            break;
        case "resdnssecnxvs":
            $resdnssecnxvs = $dataVal[0];
            break;
        case "10ms":
            $RTT10ms = $dataVal[0];
            break;
        case "10_100ms":
            $RTT10_100ms = $dataVal[0];
            break;
        case "100_500ms":
            $RTT100_500ms = $dataVal[0];
            break;
        case "500_800ms":
            $RTT500_800ms = $dataVal[0];
            break;
        case "800_1600ms":
            $RTT800_1600ms = $dataVal[0];
            break;
        case "1600ms":
            $RTT1600ms = $dataVal[0];
            break;
        case "udp4o":
            $udp4o = $dataVal[0];
            break;
        case "udp4c":
            $udp4c = $dataVal[0];
            break;
        case "udp4a":
            $udp4a = $dataVal[0];
            break;
        case "udp4f":
            $udp4f = $dataVal[0];
            break;
        case "tcp4o":
            $tcp4o = $dataVal[0];
            break;
        case "tcp4c":
            $tcp4c = $dataVal[0];
            break;
        case "tcp4a":
            $tcp4a = $dataVal[0];
            break;
        case "tcp4f":
            $tcp4f = $dataVal[0];
            break;
        case "udp4e":
            $udp4e = $dataVal[0];
            break;
        case "tcp4e":
            $tcp4e = $dataVal[0];
            break;
        case "udp4es":
            $udp4es = $dataVal[0];
            break;
        case "tcp4es":
            $tcp4es = $dataVal[0];
            break;
        case "tcp4ac":
            $tcp4ac = $dataVal[0];
            break;
        case "rawso":
            $rawso = $dataVal[0];
            break;
        case "rawsa":
            $rawsa = $dataVal[0];
            break;
        case "rawsc":
            $rawsc = $dataVal[0];
            break;
        default:
            break;
    }

}

switch ($name){
    case "INQ":
        return array($inqa, $inqns, $inqcname, $inqsoa, $inqnull, $inqptr, $inqmx, $inqtxt, $inqaaaa, $inqsrv, $inqnaptr, $inqa6, $inqds, $inqrrsig, $inqnsec, $inqnsec3, $inqnsec3param, $inqspf, $inqtkey, $inqtsig, $inqixfr, $inqaxfr, $inqstar, $inqta);
        break;
    case "OUTQ":
        return array($outqa, $outqns, $outqcname, $outqsoa, $outqnull, $outqptr, $outqmx, $outqtxt, $outqaaaa, $outqsrv, $outqnaptr, $outqa6, $outqds, $outqrrsig, $outqnsec, $outqnsec3, $outqnsec3param, $outqspf, $outqtkey, $outqtsig, $outqixfr, $outqaxfr, $outqstar, $outqta);
        break;
    case "RES":
        return array($resmis, $resipv4qs, $resipv4rr, $resnxdomr, $resservfr, $resformr, $resednsqf, $restrunrr, $resqr, $resqto, $resipv4nsaf, $resipv4nsaff, $resdnssecva, $resdnssecvs, $resdnssecnxvs);
        break;
    case "RTT":
        return array($RTT10ms, $RTT10_100ms, $RTT100_500ms, $RTT500_800ms, $RTT800_1600ms, $RTT1600ms);
        break;
    case "IO":
        return array($udp4o, $udp4c, $udp4a, $udp4f, $tcp4o, $tcp4c, $tcp4a, $tcp4f, $udp4e, $tcp4e, $udp4es, $tcp4es, $tcp4ac, $rawso, $rawsa, $rawsc);
        break;
    default:
        return print " Error function";
        break;
}

}

switch ($name){
    case "INQ":
        list($inqa, $inqns, $inqcname, $inqsoa, $inqnull, $inqptr, $inqmx, $inqtxt, $inqaaaa, $inqsrv, $inqnaptr, $inqa6, $inqds, $inqrrsig, $inqnsec, $inqnsec3, $inqnsec3param, $inqspf, $inqtkey, $inqtsig, $inqixfr, $inqaxfr, $inqstar, $inqta) = getData(${$stats}, $comm, $hostname, $name);
        print ("inqa:" . $inqa . " inqns:" . $inqns . " inqcname:" . $inqcname . " inqsoa:" . $inqsoa . " inqnull:" . $inqnull . " inqptr:" . $inqptr . " inqmx:" . $inqmx . " inqtxt:" . $inqtxt . " inqaaaa:" . $inqaaaa . " inqsrv:" . $inqsrv . " inqnaptr:" . $inqnaptr . " inqa6:" . $inqa6 . " inqds:" . $inqds . " inqrrsig:" . $inqrrsig . " inqnsec:" . $inqnsec . " inqnsec3:" . $inqnsec3 . " inqnsec3param:" . $inqnsec3param . " inqspf:" . $inqspf . " inqtkey:" . $inqtkey . " inqtsig:" . $inqtsig . " inqixfr:" . $inqixfr . " inqaxfr:" . $inqaxfr . " inqstar:" . $inqstar . " inqta:" . $inqta);
        $msg = " inqa:" . $inqa . " inqns:" . $inqns . " inqcname:" . $inqcname . " inqsoa:" . $inqsoa . " inqnull:" . $inqnull . " inqptr:" . $inqptr . " inqmx:" . $inqmx . " inqtxt:" . $inqtxt . " inqaaaa:" . $inqaaaa . " inqsrv:" . $inqsrv . " inqnaptr:" . $inqnaptr . " inqa6:" . $inqa6 . " inqds:" . $inqds . " inqrrsig:" . $inqrrsig . " inqnsec:" . $inqnsec . " inqnsec3:" . $inqnsec3 . " inqnsec3param:" . $inqnsec3param . " inqspf:" . $inqspf . " inqtkey:" . $inqtkey . " inqtsig:" . $inqtsig . " inqixfr:" . $inqixfr . " inqaxfr:" . $inqaxfr . " inqstar:" . $inqstar . " inqta:" . $inqta . "\n";
        break;
    case "OUTQ":
        list($outqa, $outqns, $outqcname, $outqsoa, $outqnull, $outqptr, $outqmx, $outqtxt, $outqaaaa, $outqsrv, $outqnaptr, $outqa6, $outqds, $outqrrsig, $outqnsec, $outqnsec3, $outqnsec3param, $outqspf, $outqtkey, $outqtsig, $outqixfr, $outqaxfr, $outqstar, $outqta) = getData(${$stats}, $comm, $hostname, $name);
        print ("outqa:" . $outqa . " outqns:" . $outqns . " outqcname:" . $outqcname . " outqsoa:" . $outqsoa . " outqnull:" . $outqnull . " outqptr:" . $outqptr . " outqmx:" . $outqmx . " outqtxt:" . $outqtxt . " outqaaaa:" . $outqaaaa . " outqsrv:" . $outqsrv . " outqnaptr:" . $outqnaptr . " outqa6:" . $outqa6 . " outqds:" . $outqds . " outqrrsig:" . $outqrrsig . " outqnsec:" . $outqnsec . " outqnsec3:" . $outqnsec3 . " outqnsec3param:" . $outqnsec3param . " outqspf:" . $outqspf . " outqtkey:" . $outqtkey . " outqtsig:" . $outqtsig . " outqixfr:" . $outqixfr . " outqaxfr:" . $outqaxfr . " outqstar:" . $outqstar . " outqta:" . $outqta);
        $msg = " outqa:" . $outqa . " outqns:" . $outqns . " outqcname:" . $outqcname . " outqsoa:" . $outqsoa . " outqnull:" . $outqnull . " outqptr:" . $outqptr . " outqmx:" . $outqmx . " outqtxt:" . $outqtxt . " outqaaaa:" . $outqaaaa . " outqsrv:" . $outqsrv . " outqnaptr:" . $outqnaptr . " outqa6:" . $outqa6 . " outqds:" . $outqds . " outqrrsig:" . $outqrrsig . " outqnsec:" . $outqnsec . " outqnsec3:" . $outqnsec3 . " outqnsec3param:" . $outqnsec3param . " outqspf:" . $outqspf . " outqtkey:" . $outqtkey . " outqtsig:" . $outqtsig . " outqixfr:" . $outqixfr . " outqaxfr:" . $outqaxfr . " outqstar:" . $outqstar . " outqta:" . $outqta . "\n";
        break;
    case "RES":
        list($resmis, $resipv4qs, $resipv4rr, $resnxdomr, $resservfr, $resformr, $resednsqf, $restrunrr, $resqr, $resqto, $resipv4nsaf, $resipv4nsaff, $resdnssecva, $resdnssecvs, $resdnssecnxvs) = getData(${$stats}, $comm, $hostname, $name);
        print ("resmis:" . $resmis . " resipv4qs:" . $resipv4qs . " resipv4rr:" . $resipv4rr . " resnxdomr:" . $resnxdomr . " resservfr:" . $resservfr . " resformr:" . $resformr . " resednsqf:" . $resednsqf . " restrunrr:" . $restrunrr . " resqr:" . $resqr . " resqto:" . $resqto . " resipv4nsaf:" . $resipv4nsaf . " resipv4nsaff:" . $resipv4nsaff . " resdnssecva:" . $resdnssecva . " resdnssecvs:" . $resdnssecvs . " resdnssecnxvs:" . $resdnssecnxvs);
        $msg = " resmis:" . $resmis . " resipv4qs:" . $resipv4qs . " resipv4rr:" . $resipv4rr . " resnxdomr:" . $resnxdomr . " resservfr:" . $resservfr . " resformr:" . $resformr . " resednsqf:" . $resednsqf . " restrunrr:" . $restrunrr . " resqr:" . $resqr . " resqto:" . $resqto . " resipv4nsaf:" . $resipv4nsaf . " resipv4nsaff:" . $resipv4nsaff . " resdnssecva:" . $resdnssecva . " resdnssecvs:" . $resdnssecvs . " resdnssecnxvs:" . $resdnssecnxvs . "\n";
        break;
    case "RTT":
        list($RTT10ms, $RTT10_100ms, $RTT100_500ms, $RTT500_800ms, $RTT800_1600ms, $RTT1600ms) = getData(${$stats}, $comm, $hostname, $name);
        print ("rsrtt10:" . $RTT10ms . " rsrtt10100:" . $RTT10_100ms . " rsrtt100500:" . $RTT100_500ms . " rsrtt500800:" . $RTT500_800ms . " rsrtt8001600:" . $RTT800_1600ms . " rsrtt1600:" . $RTT1600ms);
        $msg = " rsrtt10:" . $RTT10ms . " rsrtt10100:" . $RTT10_100ms . " rsrtt100500:" . $RTT100_500ms . " rsrtt500800:" . $RTT500_800ms . " rsrtt8001600:" . $RTT800_1600ms . " rsrtt1600:" . $RTT1600ms . "\n";
        break;
    case "IO":
        list($udp4o, $udp4c, $udp4a, $udp4f, $tcp4o, $tcp4c, $tcp4a, $tcp4f, $udp4e, $tcp4e, $udp4es, $tcp4es, $tcp4ac, $rawso, $rawsa, $rawsc) = getData(${$stats}, $comm, $hostname, $name);
        print ("udp4o:" . $udp4o . " udp4c:" . $udp4c . " udp4a:" . $udp4a . " udp4f:" . $udp4f . " tcp4o:" . $tcp4o . " tcp4c:" . $tcp4c . " tcp4a:" . $tcp4a . " tcp4f:" . $tcp4f . " udp4e:" . $udp4e . " tcp4e:" . $tcp4e . " udp4es:" . $udp4es . " tcp4es:" . $tcp4es . " tcp4ac:" . $tcp4ac . " rawso:" . $rawso . " rawsa:" . $rawsa . " rawsc:" . $rawsc);
        $msg = " udp4o:" . $udp4o . " udp4c:" . $udp4c . " udp4a:" . $udp4a . " udp4f:" . $udp4f . " tcp4o:" . $tcp4o . " tcp4c:" . $tcp4c . " tcp4a:" . $tcp4a . " tcp4f:" . $tcp4f . " udp4e:" . $udp4e . " tcp4e:" . $tcp4e . " udp4es:" . $udp4es . " tcp4es:" . $tcp4es . " tcp4ac:" . $tcp4ac . " rawso:" . $rawso . " rawsa:" . $rawsa . " rawsc:" . $rawsc . "\n";
        break;
    default:
        $msg = " Error call\n";
        break;
}

if($debugMode == "on"){
$info = "[DEBUG]Timestamp: " . date("Y-m-d H:i:s");
$nr = count(${$stats});
$sptime = microtime(true)-$initime;
$dispMsg = $info . " Bind hostname: " . $hostname . " stats: " .  $name . ". There were $nr data collected in " . number_format((float)$sptime, 3, '.', '') . " seconds. " . $msg . "\n";

file_put_contents($strLogFile, $dispMsg , FILE_APPEND | LOCK_EX);
}


exit();